All pastes #570800 Raw Edit

nvidia

public text v1 · immutable
·published 2007-06-16 21:47 UTC
rendered paste body
nvidia-installer log file '/var/log/nvidia-installer.log'
creation time: Sat Jun 16 23:03:45 2007

option status:
  license pre-accepted    : false
  update                  : false
  force update            : false
  expert                  : false
  uninstall               : false
  driver info             : false
  precompiled interfaces  : true
  no ncurses color        : false
  query latest version    : false
  OpenGL header files     : true
  no questions            : false
  silent                  : false
  no recursion            : false
  no backup               : false
  kernel module only      : false
  sanity                  : false
  add this kernel         : false
  no runlevel check       : false
  no network              : false
  no ABI note             : false
  no RPMs                 : false
  no kernel module        : false
  force SELinux           : default
  no X server check       : false
  force tls               : (not specified)
  X install prefix        : (not specified)
  X library install path  : (not specified)
  X module install path   : (not specified)
  OpenGL install prefix   : (not specified)
  OpenGL install libdir   : (not specified)
  utility install prefix  : (not specified)
  utility install libdir  : (not specified)
  doc install prefix      : (not specified)
  kernel name             : (not specified)
  kernel include path     : (not specified)
  kernel source path      : (not specified)
  kernel output path      : (not specified)
  kernel install path     : (not specified)
  proc mount point        : /proc
  ui                      : (not specified)
  tmpdir                  : /root/tmp
  ftp mirror              : ftp://download.nvidia.com
  RPM file list           : (not specified)

Using: nvidia-installer ncurses user interface
-> License accepted.
-> There appears to already be a driver installed on your system (version: 100.
   14.03).  As part of installing this driver (version: 100.14.09), the existin
   g driver will be uninstalled.  Are you sure you want to continue? ('no' will
   abort installation) (Answer: Yes)
-> No precompiled kernel interface was found to match your kernel; would you li
   ke the installer to attempt to download a kernel interface for your kernel f
   rom the NVIDIA ftp site (ftp://download.nvidia.com)? (Answer: No)
-> No precompiled kernel interface was found to match your kernel; this means
   that the installer will need to compile a new kernel interface.
-> Performing CC sanity check with CC="cc".
-> Performing CC version check with CC="cc".
-> Kernel source path: '/usr/src/linux'
-> Kernel output path: '/usr/src/linux'
-> Performing rivafb check.
-> Performing nvidiafb check.
-> Performing Xen check.
-> Cleaning kernel module build directory.
   executing: 'cd ./usr/src/nv; make clean'...
   rm -f -f nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvacpi.
   o nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvacpi.o nvidi
   a.mod.o
   rm -f -f build-in.o nv-linux.o *.d .*.{cmd,flags}
   rm -f -f nvidia.{o,ko,mod.{o,c}} nv_compiler.h *~
   rm -f -f stprof stprof.o symtab.h Modules.symvers
   rm -f -rf .tmp_versions
   rm -f Makefile
-> Building kernel module:
   executing: 'cd ./usr/src/nv; make module SYSSRC=/usr/src/linux SYSOUT=/usr/s
   rc/linux'...
   sh ./conftest.sh "cc" "cc" /usr/src/linux /usr/src/linux cc_sanity_check ful
   l_output
   sh ./conftest.sh "cc" "cc" /usr/src/linux /usr/src/linux select_makefile ful
   l_output
   make --no-print-directory -f Makefile module
   
   NVIDIA: calling KBUILD...
   make CC=cc  KBUILD_VERBOSE=1 -C /usr/src/linux SUBDIRS=/root/tmp/selfgz10783
   /NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv modules
   test -e include/linux/autoconf.h -a -e include/config/auto.conf || (		\
   	echo;								\
   	echo "  ERROR: Kernel configuration is invalid.";		\
   	echo "         include/linux/autoconf.h or include/config/auto.conf are mis
   sing.";	\
   	echo "         Run 'make oldconfig && make prepare' on kernel src to fix it
   .";	\
   	echo;								\
   	/bin/false)
   mkdir -p /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/.t
   mp_versions
   rm -f /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/.tmp_
   versions/*
   
     WARNING: Symbol version dump /usr/src/2.6.21-tmb-desktop-2mdvsmp-i586/Modu
   le.symvers
              is missing; modules will have no dependencies and modversions.
   
   make -f scripts/Makefile.build obj=/root/tmp/selfgz10783/NVIDIA-Linux-x86-10
   0.14.09-pkg1/usr/src/nv
   echo \#define NV_COMPILER \"`cc -v 2>&1 | tail -n 1`\" > /root/tmp/selfgz107
   83/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv_compiler.h
     cc -Wp,-MD,/root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/n
   v/.nv.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.2/inc
   lude -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef
   -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os -pip
   e -msoft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2 
   -march=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args -DCONFI
   G_AS_CFI=1 -DCONFIG_AS_CFI_SIGNAL_FRAME=1 -Iinclude/asm-i386/mach-bigsmp -Ii
   nclude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector -Wde
   claration-after-statement -Wno-pointer-sign -I/root/tmp/selfgz10783/NVIDIA-L
   inux-x86-100.14.09-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -
   Wf
   ormat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werr
   or  -O -fno-common -msoft-float          -MD   -Wsign-compare -Wno-cast-qual
   -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_VERSION_
   STRING=\"100.14.09\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_
   MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_M
   AP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DN
   V_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_
   RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT
   -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD
   _STR(nv)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz10783
   /NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/.tmp_nv.o /root/tmp/selfgz10783/
   NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv-linux.h:19,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv.c:14:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
   /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv.c: In fu
   nction '__nv_setup_pat_entries':
   /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv.c:946: w
   arning: comparison between signed and unsigned
   /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv.c: In fu
   nction '__nv_restore_pat_entries':
   /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv.c:972: w
   arning: comparison between signed and unsigned
   /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv.c: In fu
   nction 'nv_kern_cpu_callback':
   /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv.c:1278: 
   warning: comparison between signed and unsigned
   /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv.c:1285: 
   warning: comparison between signed and unsigned
     cc -Wp,-MD,/root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/n
   v/.nv-vm.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.2/
   include -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wun
   def -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os 
   -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundar
   y=2  -march=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args -D
   CONFIG_AS_CFI=1 -DCONFIG_AS_CFI_SIGNAL_FRAME=1 -Iinclude/asm-i386/mach-bigsm
   p -Iinclude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector
   -Wdeclaration-after-statement -Wno-pointer-sign -I/root/tmp/selfgz10783/NVID
   IA-Linux-x86-100.14.09-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswit
   ch -Wformat -Wchar-subscrip
   ts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror  -O -fno-common -m
   soft-float          -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_
   KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_VERSION_STRING=\"100.14.09\"
   -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGA
   RT_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV
   _PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRES
   ENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CH
   ANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_VMAP_4_PRESENT 
   -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_vm)"  -D"KBUI
   LD_MODNAME=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz10783/NVIDIA-Linux-x86-
   100.14.09-pkg1/usr/src/nv/.tmp_nv-vm.o /root/tmp/selfgz10783/NVIDIA-Linux-x8
   6-100.14.09-pkg1/usr/src/nv/nv-vm.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv-linux.h:19,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv-vm.c:14:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/n
   v/.os-agp.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.2
   /include -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wu
   ndef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os
   -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundar
   y=2  -march=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args -D
   CONFIG_AS_CFI=1 -DCONFIG_AS_CFI_SIGNAL_FRAME=1 -Iinclude/asm-i386/mach-bigsm
   p -Iinclude/asm-i386/mach-default -fomit-frame-pointer  -fno-
   stack-protector -Wdeclaration-after-statement -Wno-pointer-sign -I/root/tmp/
   selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv -Wall -Wimplicit -Wre
   turn-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith 
   -Wno-multichar  -Werror  -O -fno-common -msoft-float          -MD   -Wsign-c
   ompare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE
    -DNVRM -DNV_VERSION_STRING=\"100.14.09\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIG
   NAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRES
   ENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHO
   OSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PR
   ESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIR
   E_CONSOLE_SEM_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"
   KBUILD_BASENAME=KBUILD_STR(os_agp)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -
   c -o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/.tmp_o
   s-agp.o /root/tmp/selfgz10783/NVID
   IA-Linux-x86-100.14.09-pkg1/usr/src/nv/os-agp.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv-linux.h:19,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/os-agp.c:24:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/n
   v/.os-interface.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu
   /4.1.2/include -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wa
   ll -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-comm
   on -Os -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred-stack-
   boundary=2  -ma
   rch=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args -DCONFIG_A
   S_CFI=1 -DCONFIG_AS_CFI_SIGNAL_FRAME=1 -Iinclude/asm-i386/mach-bigsmp -Iincl
   ude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector -Wdecla
   ration-after-statement -Wno-pointer-sign -I/root/tmp/selfgz10783/NVIDIA-Linu
   x-x86-100.14.09-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wfo
   rmat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werro
   r  -O -fno-common -msoft-float          -MD   -Wsign-compare -Wno-cast-qual 
   -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_VERSION_
   STRING=\"100.14.09\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_
   MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_M
   AP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DN
   V_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_
   RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT
   -DNV_VMAP_4_PRESENT  -DMODULE -D"KB
   UILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_interface)"  -D"KBUILD_MODN
   AME=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.
   09-pkg1/usr/src/nv/.tmp_os-interface.o /root/tmp/selfgz10783/NVIDIA-Linux-x8
   6-100.14.09-pkg1/usr/src/nv/os-interface.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv-linux.h:19,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/os-interface.c:26:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/n
   v/.os-registry.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/
   4.1.2/include -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wal
   l -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-commo
   n -Os -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred-stack-b
   oundary=2  -march=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-a
   rgs -DCONFIG_AS_CFI=1 -DCONFIG_AS_CFI_SIGNAL_FRAME=1 -Iinclude/asm-i386/mach
   -bigsmp -Iinclude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-pro
   tector -Wdeclaration-after-statement -Wno-pointer-sign -I/root/tmp/selfgz107
   83/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type
   -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-mult
   ichar  -Werror  -O -fno-common -msoft-float          -MD   -Wsign-compare -W
   no-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM 
   -DNV_VERSION_STRING=\"100.14.09\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRU
   CT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV
   _SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_P
   RESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM
   _KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_
   PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KB
   UILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_registry)"  -D"KBUILD_MODNA
   ME=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.0
   9-pkg1/usr/src/nv/.tmp_os-registry.o /root/tmp/selfgz10783/NVIDIA-Linux-x86-
   100.14.09-pkg1/usr/src/nv/os-registry.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv-linux.h:19,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/os-registry.c:14:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/n
   v/.nv-i2c.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.2
   /include -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wu
   ndef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os
   -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundar
   y=2  -march=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args -D
   CONFIG_AS_CFI=1 -DCONFIG_AS_CFI_SIGNAL_FRAME=1 -Iinclude/asm-i386/mach-bigsm
   p -Iinclude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector
   -Wdeclaration-after-statement -Wno-pointer-sign -I/root/tmp/selfgz10783/NVID
   IA-Linux-x86-100.14.09-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswit
   ch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar 
   -Werror  -O -fno-common -msoft-float          -MD   -Wsign-compare -Wno-cast
   -qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__
    -DMODULE  -DNVRM -DNV_VERSION_STRING=\"100.14.09\" -UDEBUG -U_DEBUG -DNDEBU
   G -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_
   CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -D
   NV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BRE
   AKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -
   DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(
   s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_i2c)"  -D"KBUILD_MODNAME=KBUILD_STR(
   nvidia)" -c -o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src
   /nv/.tmp_nv-i2c.o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/
   src/nv/nv-i2c.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv-linux.h:19,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv-i2c.c:8:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     cc -Wp,-MD,/root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/n
   v/.nvacpi.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4.1.2
   /include -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wu
   ndef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -Os
   -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundar
   y=2  -march=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args -D
   CONFIG_AS_CFI=1 -DCONFIG_AS_CFI_SIGNAL_FRAME=1 -Iinclude/asm-i386/mach-bigsm
   p -Iinclude/asm-i386/mach-default -fomit-frame-pointer  -fno-stack-protector
   -Wdeclaration-after-statement -Wno-pointer-sign -I/root/tmp/selfgz10783/NVID
   IA-Linux-x86-100.14.09-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswit
   ch -Wf
   ormat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werr
   or  -O -fno-common -msoft-float          -MD   -Wsign-compare -Wno-cast-qual
   -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_VERSION_
   STRING=\"100.14.09\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_
   MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_M
   AP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DN
   V_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_
   RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT
   -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD
   _STR(nvacpi)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /root/tmp/selfgz1
   0783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/.tmp_nvacpi.o /root/tmp/self
   gz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nvacpi.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nv-linux.h:19,
                    from /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/
   usr/src/nv/nvacpi.c:15:
   include/linux/prefetch.h: In function 'prefetch_range':
   include/linux/prefetch.h:62: warning: pointer of type 'void *' used in arith
   metic
     ld -m elf_i386 -m elf_i386  -r -o /root/tmp/selfgz10783/NVIDIA-Linux-x86-1
   00.14.09-pkg1/usr/src/nv/nvidia.o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100
   .14.09-pkg1/usr/src/nv/nv-kernel.o /root/tmp/selfgz10783/NVIDIA-Linux-x86-10
   0.14.09-pkg1/usr/src/nv/nv.o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.0
   9-pkg1/usr/src/nv/nv-vm.o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-p
   kg1/usr/src/nv/os-agp.o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg
   1/usr/src/nv/os-interface.o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09
   -pkg1/usr/src/nv/os-registry.o /root/
   tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nv-i2c.o /root/tm
   p/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nvacpi.o
     Building modules, stage 2.
   make -f /usr/src/2.6.21-tmb-desktop-2mdvsmp-i586/scripts/Makefile.modpost
     scripts/mod/modpost -m -a -i /usr/src/2.6.21-tmb-desktop-2mdvsmp-i586/Modu
   le.symvers -I /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/
   nv/Module.symvers -o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/u
   sr/src/nv/Module.symvers -w  /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.0
   9-pkg1/usr/src/nv/nvidia.o
   WARNING: could not find /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg
   1/usr/src/nv/.nv-kernel.o.cmd for /root/tmp/selfgz10783/NVIDIA-Linux-x86-100
   .14.09-pkg1/usr/src/nv/nv-kernel.o
     cc -Wp,-MD,/root/tmp/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/n
   v/.nvidia.mod.o.d  -nostdinc -isystem /usr/lib/gcc/i586-mandriva-linux-gnu/4
   .1.2/include -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall
   -Wundef -Wstrict-prototypes -Wno
   -trigraphs -fno-strict-aliasing -fno-common -Os -pipe -msoft-float -mregparm
   =3 -freg-struct-return -mpreferred-stack-boundary=2  -march=i586 -mtune=gene
   ric -ffreestanding -maccumulate-outgoing-args -DCONFIG_AS_CFI=1 -DCONFIG_AS_
   CFI_SIGNAL_FRAME=1 -Iinclude/asm-i386/mach-bigsmp -Iinclude/asm-i386/mach-de
   fault -fomit-frame-pointer  -fno-stack-protector -Wdeclaration-after-stateme
   nt -Wno-pointer-sign    -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(n
   vidia.mod)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -DMODULE -c -o /root/tmp/
   selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nvidia.mod.o /root/tm
   p/selfgz10783/NVIDIA-Linux-x86-100.14.09-pkg1/usr/src/nv/nvidia.mod.c
     ld -m elf_i386 -m elf_i386 -r -o /root/tmp/selfgz10783/NVIDIA-Linux-x86-10
   0.14.09-pkg1/usr/src/nv/nvidia.ko /root/tmp/selfgz10783/NVIDIA-Linux-x86-100
   .14.09-pkg1/usr/src/nv/nvidia.o /root/tmp/selfgz10783/NVIDIA-Linux-x86-100.1
   4.09-pkg1/usr/src/nv/nvidia.mod.o
   NVIDIA: left KBUILD.
-> done.
-> Kernel module compilation complete.
ERROR: Unable to load the kernel module 'nvidia.ko'.  This happens most
       frequently when this kernel module was built against the wrong or
       improperly configured kernel sources, with a version of gcc that differs
       from the one used to build the target kernel, or if a driver such as
       rivafb/nvidiafb is present and prevents the NVIDIA kernel module from
       obtaining ownership of the NVIDIA graphics device(s).
       
       Please see the log entries 'Kernel module load error' and 'Kernel
       messages' at the end of the file '/var/log/nvidia-installer.log' for
       more information.
-> Kernel module load error: insmod: error inserting './usr/src/nv/nvidia.ko':
   -1 Invalid module format
-> Kernel messages:
   bootsplash: status on console 1 changed to on
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   14222 bytes, v3).
   bootsplash: status on console 2 changed to on
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   14222 bytes, v3).
   bootsplash: status on console 3 changed to on
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   14222 bytes, v3).
   bootsplash: status on console 4 changed to on
   bootsplash 3.1.6-2004/03/31: looking for picture...<6>...found (800x600,
   14222 bytes, v3).
   bootsplash: status on console 5 changed to on
   eth0: no IPv6 routers present
   Bluetooth: Core ver 2.8
   NET: Registered protocol family 31
   Bluetooth: HCI device and connection manager initialized
   Bluetooth: HCI socket layer initialized
   atkbd.c: Unknown key pressed (translated set 2, code 0xbc on
   isa0060/serio0).
   atkbd.c: Use 'setkeycodes e03c <keycode>' to make it known.
   atkbd.c: Unknown key released (translated set 2, code 0xbc on
   isa0060/serio0).
   atkbd.c: Use 'setkeycodes e03c <keycode>' to make it known.
   atkbd.c: Unknown key pressed (translated set 2, code 0xbc on
   isa0060/serio0).
   atkbd.c: Use 'setkeycodes e03c <keycode>' to make it known.
   atkbd.c: Unknown key released (translated set 2, code 0xbc on
   isa0060/serio0).
   atkbd.c: Use 'setkeycodes e03c <keycode>' to make it known.
   nvidia: version magic '2.6.21-tmb-desktop-2mdvsmp-i586 SMP mod_unload 586 '
   should be '2.6.17-14mdv SMP mod_unload 686 gcc-4.1'
   nvidia: version magic '2.6.21-tmb-desktop-2mdvsmp-i586 SMP mod_unload 586 '
   should be '2.6.17-14mdv SMP mod_unload 686 gcc-4.1'
   nvidia: version magic '2.6.21-tmb-desktop-2mdvsmp-i586 SMP mod_unload 586 '
   should be '2.6.17-14mdv SMP mod_unload 686 gcc-4.1'
ERROR: Installation has failed.  Please see the file
       '/var/log/nvidia-installer.log' for details.  You may find suggestions
       on fixing installation problems in the README available on the Linux
       driver download page at www.nvidia.com.